@@ -1211,6 +1211,7 @@ po_extra_files = Split('''
     ru.po
     Rules-quot
     sk.po
+    sr.po
     sl.po
     sv.po
     tr.po
@@ -1291,14 +1292,17 @@ lib_templates_files = Split('''
     ACM-siggraph.lyx
     ACM-sigplan.lyx
     agu_article.lyx
+    agutex.lyx
     apa.lyx
     beamer-conference-ornate-20min.lyx
     de_beamer-conference-ornate-20min.lyx
     dinbrief.lyx
     docbook_article.lyx
+    ectaart.lyx
     elsarticle.lyx
     es_beamer-conference-ornate-20min.lyx
     fr_beamer-conference-ornate-20min.lyx
+    frletter.lyx
     g-brief-de.lyx
     g-brief-en.lyx
     g-brief2.lyx
@@ -1312,6 +1316,7 @@ lib_templates_files = Split('''
     koma-letter2.lyx
     latex8.lyx
     letter.lyx
+    lettre.lyx
     README.new_templates
     revtex.lyx
     revtex4.lyx
@@ -1591,6 +1596,8 @@ lib_images_math_files = Split('''
     dashv.png
     ddagger.png
     ddot.png
+    dddot.png
+    ddddot.png
     ddots.png
     delim.png
     delta.png
@@ -2354,6 +2361,7 @@ lib_doc_sk_files = Split('''
 
 lib_doc_sv_files = Split('''
     Intro.lyx
+    Shortcuts.lyx
     Tutorial.lyx
 ''')
 
@@ -2598,6 +2606,16 @@ lib_examples_sl_files = Split('''
 ''')
 
 
+lib_examples_sr_files = Split('''
+    splash.lyx
+''')
+
+
+lib_examples_sv_files = Split('''
+    splash.lyx
+''')
+
+
 lib_examples_uk_files = Split('''
     splash.lyx
 ''')
@@ -2608,6 +2626,7 @@ lib_lyx2lyx_files = Split('''
     LyX.py
     lyx2lyx
     lyx2lyx_lang.py
+    lyx2lyx_tools.py
     lyx_0_06.py
     lyx_0_08.py
     lyx_0_10.py
@@ -2622,9 +2641,11 @@ lib_lyx2lyx_files = Split('''
     lyx_1_4.py
     lyx_1_5.py
     lyx_1_6.py
+    lyx_2_0.py
     parser_tools.py
     profiling.py
     test_parser_tools.py
+    unicode_symbols.py
 ''')
 
 
@@ -2642,6 +2663,7 @@ lib_layouts_files = Split('''
     acmsiggraph.layout
     agu-dtd.layout
     agums.layout
+    agutex.layout
     amsart.layout
     amsbook.layout
     apa.layout
@@ -2661,6 +2683,7 @@ lib_layouts_files = Split('''
     docbook.layout
     doublecol-new.layout
     dtk.layout
+    ectaart.layout
     egs.layout
     elsart.layout
     elsarticle.layout
@@ -2671,6 +2694,7 @@ lib_layouts_files = Split('''
     extletter.layout
     extreport.layout
     foils.layout
+    frletter.layout
     g-brief-de.layout
     g-brief-en.layout
     g-brief2.layout
@@ -2692,6 +2716,7 @@ lib_layouts_files = Split('''
     kluwer.layout
     latex8.layout
     letter.layout
+    lettre.layout
     literate-article.layout
     literate-book.layout
     literate-report.layout
